.. _configuring:

=======================
Configuration Reference
=======================

This section provides configuration options for networking-omnipath,
that needs to be set in addition to neutron configuration, for all
other configuration examples like neutron.conf and ml2_omnipath.ini,
neutron repo can be referred.

.. show-options::

    ml2_omnipath

Configuration Samples
---------------------

This section provides sample configuration file ml2_omnipath.ini


.. toctree::
   :maxdepth: 1

   samples/ml2_conf.rst
